EEG
-------

Features
^^^^^^^^^^^^^^^^
*eeg_badchannels()*
"""""""""""""""""""
.. autofunction:: neurokit2.eeg.eeg_badchannels

*eeg_diss()*
""""""""""""
.. autofunction:: neurokit2.eeg.eeg_diss

*eeg_gfp()*
""""""""""""
.. autofunction:: neurokit2.eeg.eeg_gfp

*eeg_power()*
""""""""""""""
.. autofunction:: neurokit2.eeg.eeg_power

*eeg_rereference()*
""""""""""""""""""""
.. autofunction:: neurokit2.eeg.eeg_rereference

*eeg_source()*
"""""""""""""""
.. autofunction:: neurokit2.eeg.eeg_source

*eeg_source_extract()*
"""""""""""""""""""""""
.. autofunction:: neurokit2.eeg.eeg_source_extract


MNE-Utilities
^^^^^^^^^^^^^^^^
*mne_data()*
""""""""""""""""""""
.. autofunction:: neurokit2.eeg.mne_data

*mne_to_df()*
""""""""""""""
.. autofunction:: neurokit2.eeg.mne_to_df

*mne_channel_add()*
""""""""""""""""""""
.. autofunction:: neurokit2.eeg.mne_channel_add

*mne_channel_extract()*
""""""""""""""""""""""""
.. autofunction:: neurokit2.eeg.mne_channel_extract

*mne_crop()*
""""""""""""""""""""
.. autofunction:: neurokit2.eeg.mne_crop

*mne_templateMRI()*
""""""""""""""""""""
.. autofunction:: neurokit2.eeg.mne_templateMRI



*Any function appearing below this point is not explicitly part of the documentation and should be added. Please open an issue if there is one.*


.. automodule:: neurokit2.eeg
   :members:
   :exclude-members: eeg_badchannels, eeg_diss, eeg_gfp, eeg_power, eeg_rereference, eeg_source, eeg_source_extract, mne_channel_add, mne_channel_extract, mne_crop, mne_data, mne_templateMRI, mne_to_df